pub enum SlashCommand {
Clear,
AskAI,
Fullscreen,
}Expand description
Commands that can be invoked by starting a message with a leading slash.
Variants
Implementations
Sourceimpl SlashCommand
impl SlashCommand
Sourcepub fn description(self) -> &'static str
pub fn description(self) -> &'static str
User-visible description shown in the popup.
Sourcepub fn requires_input(self) -> bool
pub fn requires_input(self) -> bool
Returns true if this command requires additional input after selection